/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-status-dialog-view
 */

(function() {
var AutoDownloadStatusDialogView;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var escape = dixim.xml.escape;
var Configs = dixim.ctt.Configs;
var $ = dixim.ctt.jQuery;
var _ = dixim.ctt.ResourceBundle.get;

/**
 * @class AutoDownloadStatusDialogView
 * @constructor
 * @param {Object} configs
 */
AutoDownloadStatusDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(AutoDownloadStatusDialogView, ModalDialogView);
dixim.autoDownload.AutoDownloadStatusDialogView = AutoDownloadStatusDialogView;
prototype = AutoDownloadStatusDialogView.prototype;
superConstructor = AutoDownloadStatusDialogView.superConstructor;

var UPDATE = 'update';

var STATE_IMAGES = {
    0: [Configs.get('imagePath'), '/ico_st_unknown.png' ].join(''),
    1: [Configs.get('imagePath'), '/ico_st_wait.png'].join(''),
    2: [Configs.get('imagePath'), '/ico_st_progress.gif'].join(''),
    retry: [Configs.get('imagePath'), '/ico_st_wait.png'].join(''),
};
var TEMPLATE_BODY_CONTENT = [
    '<div class="ctt-transfer-history-view auto-download-history-view dlg_scroll">',
    '<div id="auto-download-status-no-content">', '</div>',
    '<table id="auto-download-status-list">',
    '<colgroup>',
    '<col span="1" class="list_info">',
    '<col span="1" class="list_status">',
    '</colgroup>',
    '</table>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'auto-download-setting-dialog-'].join('');

    configs.bodyContent = TEMPLATE_BODY_CONTENT;
    configs.doubleDialog = true;
    configs.contentHeight = configs.contentHeight || '300px';
    configs.buttons = [
        {text: _('dialog_return_menu'), click: dixim.proxy(this.hide, this)},
        {text: _('dialog_update'), click: dixim.proxy(this._clickUpdate, this)},
    ];
    configs.title = _('auto_download_operation_confirm_status');

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.addRow = function(item) {
    var date = new Date();
    var year;
    var month;
    var day;
    var hour;
    var minute;
    var time;

    $('#auto-download-status-list').append([
        '<tbody id="', item.itemId, '">',
        '<tr>', '<td>',
        '<span class="list_title_s">', escape(item.title), '</span>',
        '<div class="list_detail txt_s" >',
        '<dl class="list_6em">',
        '<dt>', _('auto_download_status_date'), ':', '</dt>',
        '<dd>', '<p>', '<span class="auto-download-state-date">', '</span>', '</p>', '</dd>',
        '</dl>',
        '</div>',
        '</td>', '<td class="transfer-state-status">',
        '<div class="st_dlok">',
        '<img id="state-img-', item.itemId, '" width="40px" />',
        '<span id="transfer-status">', '</span>',
        '</div>',
        '</td>', '</tr>',
        '</tbody>',
     ].join(''));

    if (item.state === 1 && item.retryCount > 0) {
        $(['#state-img-', item.itemId].join('')).prop('src', STATE_IMAGES['retry']);
        $(['#', item.itemId, ' #transfer-status'].join('')).html( _(['auto_download_status_progress_retry'].join('')));
        $(['#', item.itemId, ' #transfer-status'].join('')).addClass('color_blue');
    } else {
        $(['#state-img-', item.itemId].join('')).prop('src', STATE_IMAGES[String(item.state)]);
        $(['#', item.itemId, ' #transfer-status'].join('')).html( _(['auto_download_status_progress_', item.state].join('')));
        if (item.state === 0) {
            $(['#', item.itemId, ' #transfer-status'].join('')).addClass('color_gray');
        } else {
            $(['#', item.itemId, ' #transfer-status'].join('')).addClass('color_blue');
        }
    }

    date.setTime(item.lastStateChangedTime * 1000);
    year = date.getFullYear();
    month = parseInt(date.getMonth(), 10)+1;
    day = ('00' + date.getDate()).slice(-2);
    hour = ('00' + date.getHours()).slice(-2);
    minute = ('00' + date.getMinutes()).slice(-2);
    time = year + '/' + month + '/' + day + '  ' + hour + ':' + minute;
    $(['#', item.itemId, ' .auto-download-state-date'].join('')).html(time);
};

prototype.noRow = function() {
    this.error(_('auto_download_status_no_content'));
};

prototype.error = function(text) {
    var selector = $('#auto-download-status-no-content');

    selector.html([
        '<span>', text, '</span>',
    ].join(''));
    selector.addClass('txt_none').addClass('error-text-field');
};

prototype.cleanList = function() {
    $('#auto-download-status-list tbody').remove();
};

prototype._clickUpdate = function() {
    this.dispatchEvent(new Event(UPDATE));
};

}());
