/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-wizard-howto-dialog-view
 */

(function() {
var AutoDownloadWizardHowtoDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var Form = dixim.ctt.util.Form;
var Event = dixim.event.Event;
var $ = dixim.ctt.jQuery;

/**
 * @class AutoDownloadWizardHowtoDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
AutoDownloadWizardHowtoDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(AutoDownloadWizardHowtoDialogView, ModalDialogView);
dixim.autoDownload.AutoDownloadWizardHowtoDialogView = AutoDownloadWizardHowtoDialogView;
superConstructor = AutoDownloadWizardHowtoDialogView.superConstructor;
prototype = AutoDownloadWizardHowtoDialogView.prototype;

var NEXT = 'next';
var TEMPLATE_BODY_CONTENT = [
    '<div id="auto-download-howto-description" class="description-field dlg_main_msg">',
    '<span>', '${description}', '</span>',
    '</div>',
    '<div id="auto-download-howto-field" class="list-field dl_tbl">',
        '<dl>',
        '<dt>', '${sdFirstTitle}', '</dt>',
        '<dd>',
        '<label class="select-pointer">', '<input id="sdFirst" type="checkbox" />',
        '<span>', '${sdFirstDescription}', '</span>',
        '</label>',
        '</dd>',
        '</dl>',
        '<dl class="none_border_bottom">',
        '<dt>', '${timingTitle}', '</dt>',
        '<dd>',
        '<div>',
        '<label class="select-pointer">',
        '<input type="radio" name="timing" id="timing_asap" data-role="none" />',
        '<span>', '${timingAsap}', '</span>',
        '</label>',
        '</div>',
        '<div>',
        '<label class="select-pointer">',
        '<input type="radio" name="timing" id="timing_timed" data-role="none" />',
        '<span>', '${timingTimed}', '</span>',
        '</label>',
        '<div id="timing_schedule">', '${timeSelector}', '</div>',
        '</div>',
        '</dd>',
        '</dl>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'auto-download-wizard-howto-dialog-'].join('');

    configs.title = configs.title;

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('auto_download_howto_description'))
        .replace('${sdFirstTitle}', _('auto_download_howto_sd_first_title'))
        .replace('${sdFirstDescription}', _('auto_download_howto_sd_first_description'))
        .replace('${timingTitle}', _('auto_download_howto_timing_title'))
        .replace('${timingAsap}', _('auto_download_howto_timing_asap'))
        .replace('${timingTimed}', _('auto_download_howto_timing_timed'))
        .replace('${timeSelector}', Form.createTimeSelector({template: '${hour}${min}'}));

    configs.contentHeight = configs.contentHeight || 'auto';
    configs.buttons = [
        {text: _('dialog_return_menu'), click: dixim.proxy(this.hide, this)},
        {text: _('dialog_next'), click: dixim.proxy(this._clickNext, this)},
    ];

    this._taskInfo = configs.taskInfo;

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    var hour;
    var min;

    if (this._taskInfo !== null) {
         if (this._taskInfo.sdFirst) {
             $('#sdFirst').trigger('click');
         }
         if (this._taskInfo.reservationType === 'timed') {
             $('#timing_timed').trigger('click');
             hour = Math.floor(this._taskInfo.timedReservationStartTime / 60);
             min = this._taskInfo.timedReservationStartTime % 60;
             $('[name="hour"]').val(hour);
             $('[name="min"]').val(min);
         }
    }

    this._changeTiming();
    $('[name="timing"]').on('click', dixim.proxy(this._changeTiming, this));

    superConstructor.prototype._render.call(this);
};

prototype._changeTiming = function() {
    if ($('[name="timing"]:checked').length === 0) {
        $('#timing_asap').prop('checked', true);
    }

    if (! $('#timing_timed').prop('checked')) {
        $('#timing_schedule select').prop('disabled', true);
    } else {
        $('#timing_schedule select').prop('disabled', false);
    }
};

prototype._clickNext = function() {
    var info = {};
    var hour;
    var min;

    if ($('#sdFirst').prop('checked')) {
        info.sdFirst = true;
    }

    if ($('#timing_timed').prop('checked')) {
        hour = parseInt($('#timing_schedule [name="hour"]').val(), 10);
        min = parseInt($('#timing_schedule [name="min"]').val(), 10);

        info.startTime = (hour * 60) + min;
    }
    this.dispatchEvent(new Event(NEXT, info));
};

}());
