/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule setting-menu-dialog-controller
 */

(function() {
var SettingMenuDialogController;
var prototype;
var superConstructor;
var SettingMenuDialogView = dixim.autoDownload.SettingMenuDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var AutoDownloadSettingDialogController = dixim.autoDownload.AutoDownloadSettingDialogController;
var AutoDownloadHistoryDialogController = dixim.autoDownload.AutoDownloadHistoryDialogController;
var FilterSettingDialogController = dixim.autoDownload.FilterSettingDialogController;

/**
 * @class SettingMenuDialogController
 * @constructor
 * @param {Object} configs
 */
SettingMenuDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(SettingMenuDialogController, EventTarget);
dixim.autoDownload.SettingMenuDialogController = SettingMenuDialogController;
prototype = SettingMenuDialogController.prototype;
superConstructor = SettingMenuDialogController.superConstructor;

var SAVE_SETTING = 'saveSetting';
var FILTER_SETTING = 'filterSetting';
var SAVE_HISTORY = 'saveHistory';
var UPDATE = 'update';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'setting-menu-dialog'].join('');

    this._view = new SettingMenuDialogView(configs);
    this._view.addEventListener(SAVE_SETTING, this._clickSaveSetting, this);
    this._view.addEventListener(FILTER_SETTING, this._clickFilterSetting, this);
    this._view.addEventListener(SAVE_HISTORY, this._clickSaveHistory, this);
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickSaveSetting = function() {
    var controller;

    controller = new AutoDownloadSettingDialogController();
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickFilterSetting = function() {
    var controller;

    controller = new FilterSettingDialogController();
    controller.start();
};

prototype._clickSaveHistory = function() {
    var controller;

    controller = new AutoDownloadHistoryDialogController();
    controller.start();
};

prototype._callbackUpdate = function() {
    this.stop();
    this.dispatchEvent(new Event(UPDATE));
};

prototype._errorDialog = function(title, text) {
    var query = {};
    var dialog;

    query.id = this._id;
    query.title = title;
    query.description = text;
    query.doubleDialog = true;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
