/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule transfer-reservation-edit-dialog-controller
 */

(function() {
var TransferReservationEditDialogController;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var TransferReservationEditDialogView = dixim.contents.TransferReservationEditDialogView;
var ApiClientTransfer = dixim.common.ApiClientTransfer;

/**
 * @class TransferReservationEditDialogController
 * @constructor
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {MobileAutoDownloadApiClient} [configs.model]
 */
TransferReservationEditDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(TransferReservationEditDialogController, EventTarget);
dixim.contents.TransferReservationEditDialogController = TransferReservationEditDialogController;
prototype = TransferReservationEditDialogController.prototype;
superConstructor = TransferReservationEditDialogController.superConstructor;

var EDIT = 'edit';
var UPDATE = 'update';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {ApiClientTransfer} [configs.model]
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._model = new ApiClientTransfer();
    this._model.addEventListener('changeReservation', this._successUpdateReservation, this);
    this._model.addEventListener('changeReservationError', this._errorUpdateReservation, this);

    this._view = new TransferReservationEditDialogView(configs);
    this._view.addEventListener(EDIT, this._settingReservationDate, this);

    this._info = configs.info || {};
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._settingReservationDate = function(e) {
    var query;

    query = {
        id : this._info.id,
        start_time : e.args,
    };
    this._view.startIndicator();
    this._model.changeReservation(query);
};

prototype._successUpdateReservation = function() {
    this._view.stopIndicator();
    this._view.hide();
    this.dispatchEvent(new Event(UPDATE));
};

prototype._errorUpdateReservation = function() {
    this._view.stopIndicator();
    this._view._errorDialog();
};

}());
