/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule transfer-wizard-select-dst-dialog-view
 */

(function() {
var TransferWizardSelectDstDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var Configs = dixim.ctt.Configs;
var $ = dixim.ctt.jQuery;

/**
 * @class TransferWizardSelectDstDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
TransferWizardSelectDstDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(TransferWizardSelectDstDialogView, ModalDialogView);
dixim.contents.TransferWizardSelectDstDialogView = TransferWizardSelectDstDialogView;
superConstructor = TransferWizardSelectDstDialogView.superConstructor;
prototype = TransferWizardSelectDstDialogView.prototype;

var CLOSE = 'close';
var CLEAR_SERVER = 'clearServer';
var SELECT_SERVER = 'selectServer';
var TEMPLATE_BODY_CONTENT = [
    '<div class="description-field dlg_main_msg">',
    '<span>', '${description}', '</span>',
    '</div>',
    '<div class="modal_hd_btns">',
    '<label>',
    '<button id="serverListClear" class="modal-dialog-operate-buttons ui-btn ui-shadow ui-corner-all">', '${clearBtn}', '</button>',
    '</label>',
    '</div>',
    '<div id="server-list-field" class="list-field dlg_scroll list_next exist_operation">',
    '<table>', '</table>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'transfer-wizard-select-dst-dialog-'].join('');

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('contents_transfer_wizard_dst_description'))
        .replace('${clearBtn}', _('action_bar_server_clear'));

    configs.title = _('contents_operation_menu_transfer');
    configs.doubleDialog = true;
    configs.contentHeight = configs.contentHeight || '300px';
    configs.buttons = [
        {text: _('dialog_return_menu'), click: dixim.proxy(this._clickClose, this)},
    ];

    this._noActiveServerList = [];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    $(['#body-content-', this._id].join('')).find('.modal_hd_btns label').on('click', dixim.proxy(this._clickClearServer, this));

    superConstructor.prototype._render.call(this);
};

prototype.changeOperationButton = function(isEnable) {
    var operateBtn = $(['#body-content-', this._id].join('')).find('.modal_hd_btns label');

    if (isEnable) {
        operateBtn.on('click', dixim.proxy(this._clickClearServer, this));
    } else {
        operateBtn.off('click');
    }

    $('#serverListClear').prop('disabled', (!isEnable));
};

prototype.addRow = function(server) {
    var bodySelector = $(['#body-content-', this._id].join(''));
    var tableSelector = bodySelector.find('#server-list-field table');
    var rowSelector;

    tableSelector.append([
        '<tr>',
        '<td>', '<img class="contents-img">', '</td>',
        '<td>', '<span name="content-title" class="content-title">', '</span>', '</td>',
        '</tr>',
    ].join(''));

    rowSelector = tableSelector.find('tr:last-child');
    rowSelector.find('[name="content-title"]').text(server.friendlyName);

    if (server.deviceIcon === '') {
        rowSelector.find('img').prop('src', [Configs.get('imagePath'), '/ico_list_server.png'].join(''));
    } else {
        rowSelector.find('img').prop('src', server.deviceIcon).error(function() {
            $(this).prop('src', [Configs.get('imagePath'), '/ico_list_server.png'].join(''));
        });
    }

    if (!!!server.alive) {
        this._noActiveServerList.push(server);
        rowSelector.addClass('noactive');
    }

    rowSelector.on('click', server, dixim.proxy(this._clickServer, this));
};

prototype.noRow = function() {
    this.error(_('contents_transfer_wizard_dst_no_server'));
};

prototype.error = function(text) {
    var bodySelector = $(['#body-content-', this._id].join(''));

    bodySelector.find('#server-list-field').html([
        '<div class="txt_none error-text-field">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.clearDmsList = function() {
    var bodySelector = $(['#body-content-', this._id].join(''));
    var tableSelector = bodySelector.find('#server-list-field table');

    this._noActiveServerList = [];
    tableSelector.empty();
};

prototype._clickClearServer = function() {
    this.dispatchEvent(new Event(CLEAR_SERVER, this._noActiveServerList));
};

prototype._clickClose = function() {
    this.hide();
    this.dispatchEvent(new Event(CLOSE));
};

prototype._clickServer = function(e) {
    this.dispatchEvent(new Event(SELECT_SERVER, {server: e.data}));
};

}());
