/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule auto-delete-view
 */

(function() {
var AutoDeleteView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class AutoDeleteView
 * @constructor
 * @param {Object} configs
 */
AutoDeleteView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AutoDeleteView, EventTarget);
dixim.server.AutoDeleteView = AutoDeleteView;
prototype = AutoDeleteView.prototype;
superConstructor = AutoDeleteView.superConstructor;

var APPLY = 'apply';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = _('server_menu_auto_delete');
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<div class="dl_tbl">',
        '<dl>',
        '<dt>', _('server_auto_delete_availability_title'), '</dt>',
        '<dd>',
        '<p>', '<span>', _('server_auto_delete_availability_description'), '</span>', '</p>',
        '<label class="select-pointer">',
        '<input type="radio" id="auto_delete_availability_true" name="autodelete_radio_yes_no" data-role="none" />',
        '<span>', _('server_auto_delete_availability_true'), '</span>',
        '</label>',
        '<label class="select-pointer">',
        '<input type="radio" id="auto_delete_availability_false" name="autodelete_radio_yes_no" data-role="none" />',
        '<span>', _('server_auto_delete_availability_false'), '</span>',
        '</label>',
        '</dd>',
        '</dl>',
        '<dl>',
        '<dt>', _('server_auto_delete_threshold_title'), '</dt>',
        '<dd>',
        '<p>', '<span id="auto_delete_threshold_description">', _('server_auto_delete_threshold_description'), '</span>', '</p>',
        '<input type="text" id="auto_delete_threshold" maxlength="4" size="4" data-role="none" />', _('server_auto_delete_threshold_unit'),
        '</dd>',
        '</dl>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    UiUtils.setActionBar('ab_apply', dixim.proxy(this._clickApply, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().off('click').on('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype.setAvailabilityValue = function(isEnable) {
    if (isEnable) {
        $('#auto_delete_availability_true').prop('checked', true);
        $('#auto_delete_availability_false').prop('checked', false);
    } else {
        $('#auto_delete_availability_true').prop('checked', false);
        $('#auto_delete_availability_false').prop('checked', true);
    }
};

prototype.setThresholdLimitValue = function(val) {
    $('#auto_delete_threshold_description').html(_('server_auto_delete_threshold_description', val));
};

prototype.setThresholdValue = function(val) {
    $('#auto_delete_threshold').val(val);
};

prototype._clickApply = function() {
    var data = {};

    data.availability = $('#auto_delete_availability_true').prop('checked');
    data.threshold = $('#auto_delete_threshold').val();

    this.dispatchEvent(new Event(APPLY, data));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

}());
