/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule parental-menu-controller
 */

(function() {
var ParentalMenuController;
var prototype;
var superConstructor;
var ParentalMenuView = dixim.server.ParentalMenuView;
var EventTarget = dixim.event.EventTarget;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var ParentalOperationController = dixim.server.ParentalOperationController;
var ParentalDefaultSettingController = dixim.server.ParentalDefaultSettingController;
var ParentalCheckDialogController = dixim.server.ParentalCheckDialogController;
var ParentalEditSettingController = dixim.server.ParentalEditSettingController;
var ParentalEditPinController = dixim.server.ParentalEditPinController;
var PinManager = dixim.ctt.util.PinManager;

/**
 * @class ParentalMenuController
 * @constructor
 * @param {Object} configs
 */
ParentalMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ParentalMenuController, EventTarget);
dixim.server.ParentalMenuController = ParentalMenuController;
prototype = ParentalMenuController.prototype;
superConstructor = ParentalMenuController.superConstructor;

var EDIT_SETTING = 'editSetting';
var EDIT_PIN = 'editPin';
var SUCCESS = 'success';
var ERROR = 'error';
var PREV = 'prev';
var UPDATE_PIN = 'updatePin';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'parental-menu'].join('');

    this._view = new ParentalMenuView(configs);
    this._view.addEventListener(PREV, this._clickPrev, this);
    this._view.addEventListener(EDIT_SETTING, this._clickEditSetting, this);
    this._view.addEventListener(EDIT_PIN, this._clickEditPin, this);

    this._parentContext = configs.parentContext;
    this._dialog = null;
    this._pinCode;
};

/**
 * @method start
 */
prototype.start = function() {
    if (typeof this._pinCode === 'undefined') {
        this._authenticate();
    } else {
        this._view.show();
    }
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._authenticate = function() {
    var query = {};
    var controller;

    controller = new ParentalCheckDialogController(query);
    controller.addEventListener(SUCCESS, this._successCheckPinCode, this);
    controller.addEventListener(ERROR, this._errorCheckPinCode, this);
    controller.start();
};

prototype._successCheckPinCode = function(e) {
    this._pinCode = e.args.pinCode;
    this.start();
};

prototype._errorCheckPinCode = function() {
    this._errorDialog(_('server_parental_menu_error_pin'));
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._clickEditSetting = function() {
    var query = {};
    var controller;

    query.parentContext = this;
    query.pinCode = this._pinCode;
    controller = new ParentalEditSettingController(query);
    controller.start();
};

prototype._clickEditPin = function() {
    var query = {};
    var controller;

    query.parentContext = this;
    query.pinCode = this._pinCode;
    controller = new ParentalEditPinController(query);
    controller.addEventListener(UPDATE_PIN, this._callbackUpdatePin, this);
    controller.start();
};

prototype._callbackUpdatePin = function(e) {
    this._pinCode = e.args.code;
};

prototype._errorDialog = function(text) {
    var query = {};

    query.id = this._id;
    query.title = _('server_menu_parental');
    query.description = text;
    this._dialog = new ErrorModalDialogView(query);
    this._dialog.show();
};

}());
