/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule vdms-menu-controller
 */

(function() {
var VdmsMenuController;
var prototype;
var superConstructor;
var VdmsMenuView = dixim.vdms.VdmsMenuView;
var EventTarget = dixim.event.EventTarget;
var UiFunctionManager = dixim.ctt.util.UiFunctionManager;
var Configs = dixim.ctt.Configs;
var ResourceBundle = dixim.ctt.ResourceBundle;
var VdmsBootController = dixim.vdms.VdmsBootController;
var ActivationController = dixim.vdms.ActivationController;
var PermissionMenuController = dixim.vdms.PermissionMenuController;
var PairingController = dixim.vdms.PairingController;
var AggregationMenuController = dixim.vdms.AggregationMenuController;
var ContentsDistributionSettingController = dixim.vdms.ContentsDistributionSettingController;
var ApiClientVdms = dixim.common.ApiClientVdms;

/**
 * @class VdmsMenuController
 * @constructor
 * @param {Object} configs
 */
VdmsMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(VdmsMenuController, EventTarget);
dixim.vdms.VdmsMenuController = VdmsMenuController;
prototype = VdmsMenuController.prototype;
superConstructor = VdmsMenuController.superConstructor;

var checkWorkingVdms = function() {
    var model = new ApiClientVdms();
    var success = function() {
        UiFunctionManager.set('vdms');
    };

    model.addEventListener('fetchDmsStatus', success, this);
    model.fetchDmsStatus();
};
checkWorkingVdms();

var BOOT_SERVER = 'bootServer';
var ACTIVATION = 'activation';
var PERMISSION = 'permission';
var PAIRING = 'pairing';
var AGGREGATION = 'aggregation';
var DISTRIBUTION = 'distribution';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    ResourceBundle.reset();
    Configs.set('resourceBundlePath', 'lang/vdms/');

    this._view = new VdmsMenuView(configs);
    this._view.addEventListener(BOOT_SERVER, this._clickBootServer, this);
    this._view.addEventListener(ACTIVATION, this._clickActivation, this);
    this._view.addEventListener(PERMISSION, this._clickPermission, this);
    this._view.addEventListener(PAIRING, this._clickPairing, this);
    this._view.addEventListener(AGGREGATION, this._clickAggregation, this);
    this._view.addEventListener(DISTRIBUTION, this._clickDistribution, this);
    this._view.addEventListener(PREV, this._clickPrev, this);

    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickBootServer = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new VdmsBootController(query);
    controller.start();
};

prototype._clickActivation = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new ActivationController(query);
    controller.start();
};

prototype._clickPermission = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new PermissionMenuController(query);
    controller.start();
};

prototype._clickPairing = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new PairingController(query);
    controller.start();
};

prototype._clickAggregation = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new AggregationMenuController(query);
    controller.start();
};

prototype._clickDistribution = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new ContentsDistributionSettingController(query);
    controller.start();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

}());
