/**
 * @module ctt
 * @submodule schedule-entry-listing-wizard-page-controller
 */
(function() {
var Event = dixim.event.Event;
var WizardPageController = dixim.ctt.WizardPageController;
var ScheduleEntryListingWizardPageView = dixim.ctt.ScheduleEntryListingWizardPageView;
var ScheduleEntryListingController = dixim.ctt.ScheduleEntryListingController;
var ScheduleEntryEditWizardPageController = dixim.ctt.ScheduleEntryEditWizardPageController;
var ScheduleEntryDeletionWizardPageController = dixim.ctt.ScheduleEntryDeletionWizardPageController;
var ContentsTransferApiClient = dixim.ctt.api.ContentsTransferApiClient;

var ScheduleEntryListingWizardPageController;
var prototype;
var superConstructor;

/**
 * @class ScheduleEntryListingWizardPageController
 * @constructor
 * @param {Object} configs
 */
ScheduleEntryListingWizardPageController = function(configs) {
  WizardPageController.call(this, configs);
};
dixim.inherit(ScheduleEntryListingWizardPageController, WizardPageController);
dixim.ctt.ScheduleEntryListingWizardPageController = ScheduleEntryListingWizardPageController;
prototype = ScheduleEntryListingWizardPageController.prototype;
superConstructor = ScheduleEntryListingWizardPageController.superConstructor;

/**
 * @event done
 */
var DONE = 'done';

/**
 * Triggered when the status dialog has been closed.
 * 
 * @event close
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  superConstructor.prototype._initialize.call(this, configs);

  this._entryListingController = null;
  this._view = new ScheduleEntryListingWizardPageView();
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('close', this._didClickClose, this);
  v.addEventListener('delete', this._didClickDelete, this);
  v.addEventListener('update', this._didClickUpdate, this);
  v.addEventListener('render', this._didRenderView, this);
  v.show();

  if (!!this._entryListingController) {
    this._entryListingController.start(); 
    this._fetchReservationList();
  }
  superConstructor.prototype.start.call(this);
};

prototype._didRenderView = function(e) {
  var lc;
  var w = this._wizard;
  var m;

  m = w.getRegistryEntry('model');
  m.addEventListener('reservationList', this._didFetchReservationList, this);
  m.addEventListener('reservationListError', this._didFailFetchReservationList, this);
  this._model = m;

  lc = new ScheduleEntryListingController({
    containerNode: this._view.getBodyContent()
  });
  lc.addEventListener('changeSelection', this._didChangeSelection, this);

  this._entryListingController = lc;
};

prototype._fetchReservationList = function(e) {
  if (!!this._session) return;
  this._session = this._model.reservationList();
};

prototype._didClickClose = function(e) {
  this._stop();
  this.dispatchEvent(new Event(DONE));
};

prototype._didClickUpdate = function(e) {
  var vc;
  var w = this._wizard;
  var rows;

  rows = this._entryListingController.getSelectedEntries();
  w.setRegistryEntry('targetEntries', rows);

  vc = new ScheduleEntryEditWizardPageController();
  w.pushViewController(vc);
};

prototype._didClickDelete = function(e) {
  var vc;
  var w = this._wizard;
  var rows;

  rows = this._entryListingController.getSelectedEntries();
  w.setRegistryEntry('targetEntries', rows);

  vc = new ScheduleEntryDeletionWizardPageController();
  w.pushViewController(vc);
};

prototype._didChangeSelection = function(e) {
  var v = this._view;
  var list;
  var len;

  list = this._entryListingController.getSelectedEntries();
  len = list.length;

  if (!len) {
    v.disableUpdateButton();
    v.disableDeleteButton();
    return;
  }

  v.enableDeleteButton();
  if (len === 1) {
    v.enableUpdateButton();
  } else {
    v.disableUpdateButton();
  }
};

prototype._didFetchReservationList = function(e) {
  this._session = null;
  this._entryListingController.update(e.args.data.results);
};

prototype._didFailFetchReservationList = function(e) {
  this._session = null;
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._stop();
  superConstructor.prototype.stop.call(this);
};

prototype._stop = function() {
  if (!!this._entryListingController) {
    this._entryListingController.stop();
  }
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  if (!!this._entryListingController) {
    this._entryListingController.destroy();
    this._entryListingController = null;
  }
  this._view.destroy();
  superConstructor.prototype.destroy.call(this);
};

}());
