/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule progress-dialog-controller
 */

(function() {
var EventTarget = dixim.event.EventTarget;
var ProgressDialogView = dixim.ctt.ad.ProgressDialogView;
var ContentsTransferApiClient = dixim.ctt.api.ContentsTransferApiClient;

var ProgressDialogController;
var prototype;

/**
 * @class ProgressDialogController
 * @constructor
 * @param {Object} configs
 * @param {ContentsTransferApiClient} [configs.model]
 */
ProgressDialogController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(ProgressDialogController, EventTarget);
dixim.ctt.ad.ProgressDialogController = ProgressDialogController;
prototype = ProgressDialogController.prototype;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._model = configs.model || new ContentsTransferApiClient();
  this._view = new ProgressDialogView(configs);
  this._session = null;
  this._queue = [];
  this._processing = configs.processing;
  this._didFinishedFunction = configs.finish || null;
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('close', this._didClickClose, this);

  v.show();
  this._view.inProgress();
  this._processing();
};

prototype._didClickClose = function() {
  this._view.destroy();
};

prototype._didFinish = function() {
  this._view.finish();
  if (typeof this._didFinishedFunction === "function") {
    this._didFinishedFunction();
  }
};

/**
 * @method finish
 */
prototype.finish = function() {
  this._didFinish();
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

}());
