/**
 * @module dixim
 * @submodule common
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule progress-modal-dialog-view
 */

(function() {
var ProgressModalDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

/**
 * @class ProgressModalDialogView
 * @constructor
 * @param {Object} configs
 */
ProgressModalDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(ProgressModalDialogView, ModalDialogView);
dixim.common.ProgressModalDialogView = ProgressModalDialogView;
prototype = ProgressModalDialogView.prototype;
superConstructor = ProgressModalDialogView.superConstructor;

var CLOSE = 'close';
var YES = 'yes';
var COMPLETE = 'complete';

var TEMPLATE_BODY_CONTENT = [
    '<div>',
    '<div class="ctt-progress-view-description dlg_main_msg">', '${description}', '</div>',
    '<div class="ctt-progress-view">',
    '<div class="ctt-progress-view-progress txt_gray">', '</div>',
    '</div>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'progress-modal-dialog-'].join('');
    configs.bodyContent = TEMPLATE_BODY_CONTENT.
        replace('${description}', configs.description);

    configs.closeButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {
            text: _('dialog_close'),
            click: dixim.proxy(this.hide, this),
        },
        {
            text: _('dialog_ok'),
            click: dixim.proxy(this._clickYes, this),
        },
    ];

    this._contents = $.merge([], configs.contents);
    this._contentsLen = this._contents.length;
    this._nameKey = configs.nameKey || '';
    this._progressStr = configs.progressStr;

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.decrementDescription = function() {
    var data = this._contents.shift();
    var name = '';

    if (typeof data === 'undefined') {
        this.hide();
        this.stopSpecifiedIndicator($('.ctt-progress-view-description'));
        this.dispatchEvent(new Event(COMPLETE));
        return;
    }

    if (this._nameKey in data) {
        name = data[this._nameKey];
    }
    $('.ctt-progress-view-description').html([
        _('progress_description', this._progressStr),
    ].join(''));
    $('.ctt-progress-view-progress').text(_('progress_info', this._progressStr, name, this._contentsLen - this._contents.length, this._contentsLen));
};

prototype._clickYes = function() {
    this.decrementDescription();
    this.startSpecifiedIndicator($('.ctt-progress-view-description'));
    this.dispatchEvent(new Event(YES));
};

}());
