/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule contents-view
 */

(function() {
var ContentsView;
var prototype;
var superConstructor;
var Formatter = dixim.ctt.util.Formatter;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var Configs = dixim.ctt.Configs;
var UiUtils = dixim.common.UiUtils;
var Template = dixim.ctt.util.Template;
var $ = dixim.ctt.jQuery;
var Enum = dixim.ctt.util.Enum;

/**
 * @class ContentsView
 * @constructor
 * @param {Object} configs
 */
ContentsView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ContentsView, EventTarget);
dixim.contents.ContentsView = ContentsView;
prototype = ContentsView.prototype;
superConstructor = ContentsView.superConstructor;

var SELECT = 'select';
var SELECT_CONTENT = 'selectContent';
var OPERATE = 'operate';
var REFRESH = 'refresh';
var SEARCH = 'search'
var PREV = 'prev';
var CHANGE_CHECKBOX = 'changeCheckbox';

var OperationMenu = Enum.fetch('OPERATION_MENU');

var TEMPLATE_LOADING = Template.LOADING_ICON_LARGE;
var CONTENTS_IMAGES = {
    '-1': [Configs.get('imagePath'), '/ico_list_mvno.png'].join(''),
    '1': [Configs.get('imagePath'), '/ico_list_mv1.png'].join(''),
    '2': [Configs.get('imagePath'), '/ico_list_mv2.png'].join(''),
    '3': [Configs.get('imagePath'), '/ico_list_mv3.png'].join(''),
    '4': [Configs.get('imagePath'), '/ico_list_mv4.png'].join(''),
    '5': [Configs.get('imagePath'), '/ico_list_mv5.png'].join(''),
    '6': [Configs.get('imagePath'), '/ico_list_mv6.png'].join(''),
    '7': [Configs.get('imagePath'), '/ico_list_mv7.png'].join(''),
    '8': [Configs.get('imagePath'), '/ico_list_mv8.png'].join(''),
    '9': [Configs.get('imagePath'), '/ico_list_mv9.png'].join(''),
    '10': [Configs.get('imagePath'), '/ico_list_mv10.png'].join(''),
    'uploadable': [Configs.get('imagePath'), '/ico_list_mvno.png'].join(''),
    'free': [Configs.get('imagePath'), '/ico_list_mv.png'].join(''),
    'nosecureV': [Configs.get('imagePath'), '/ico_list_nosecure_v.png'].join(''),
    'nosecureM': [Configs.get('imagePath'), '/ico_list_nosecure_m.png'].join(''),
    'nosecureP': [Configs.get('imagePath'), '/ico_list_nosecure_p.png'].join(''),
    'folder': [Configs.get('imagePath'), '/ico_list_folder.png'].join(''),
};

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = _('contents_menu_media_contents');
    this._browsedData = {};
    this._contentName = new this._contentNameClosure();
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<ul id="contentField" class="content_field list_btn txt_m list_next list_menu">',
        '</ul>',
        '</div>',
        '</div>',
    ].join(''));

    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    UiUtils.setActionBar('ab_select', dixim.proxy(this._clickSelect, this));
    UiUtils.setActionBar('ab_operate', dixim.proxy(this._clickOperate, this));
    UiUtils.disableActionBar('ab_select');
    UiUtils.disableActionBar('ab_operate');
    UiUtils.showActionSettingBar('ac_refresh', dixim.proxy(this._clickRefresh, this));
    UiUtils.showActionSettingBar('hc_search', dixim.proxy(this._clickSearch, this));

    this.setContentName(this._title);
    $('.btn_prev').off('click').show().on('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
   $('.rootPage').empty();
};

prototype._contentNameClosure = function() {
    var stack = [];

    return {
        push: function(name) {
            $('.art_tit').text(name);
            stack.push(name);
        },
        pop: function() {
            stack.pop();
            $('.art_tit').text(stack[stack.length - 1]);
        },
    }
};

prototype.setContentName = function(name) {
    this._contentName.push(name);
};

prototype.unsetContentName = function() {
    this._contentName.pop();
};

prototype.startLoading = function() {
    this.stopLoading();
    $('.contents_inner').append([
        '<div id="loading_icon">', TEMPLATE_LOADING, '</div>',
    ].join(''));
};

prototype.stopLoading = function() {
    $('#loading_icon').remove();
};

prototype._getImageSrc = function(data) {
    if (data.class === 'container') {
        return CONTENTS_IMAGES['folder'];
    }

    if (typeof data.thumbnailUrl !== 'undefined' && data.thumbnailUrl !== '') return data.thumbnailUrl;

    switch(data.mediaType) {
        case 'video':
            if (/^DTCP_/.test(data.profile) || (data.profile === '' && /.dtcp$/.test(data.url))) {
                if (typeof data.copyCount === 'undefined') {
                    return (data.uploadable) ? CONTENTS_IMAGES['free'] : CONTENTS_IMAGES['uploadable'];
                } else {
                    return CONTENTS_IMAGES[data.copyCount];
                }
            }
            return CONTENTS_IMAGES['nosecureV'];
        case 'audio':
            return CONTENTS_IMAGES['nosecureM'];
        case 'image':
            return CONTENTS_IMAGES['nosecureP'];
    }
};

prototype.addContent = function(data, isCategory) {
    var id = $('#contentField li').length;
    var rowSelector;

    this._browsedData[id] = data;

    $('#contentField').append([
        '<li>',
        '<table>',
        '<tr>',
        '<td id="checkbox_', id, '" class="contents_icon">', '</td>',
        '<td class="contents_icon" name="clickable">', '<img class="contents-img" src="', this._getImageSrc(data), '">', '</td>',
        '<td class="contents_title" name="clickable">',
        '<p class="content-title txt_m">', data.title, '</p>',
        '<div class="list_detail txt_s">', '</div>',
        '</td>',
        '</tr>',
        '</table>',
        '</li>',
    ].join(''));

    rowSelector = $('#contentField li:last-child');

    switch(data.mediaType) {
        case 'image':
            rowSelector.find('img').error(function() {
                $(this).prop('src', CONTENTS_IMAGES['nosecureP']);
            });
            break;
        default:
            break;
    }

    if (!isCategory || data.class === 'item') {
        rowSelector.find(['#checkbox_', id].join('')).html([
            '<label class="checkbox_contents">', '<input type="checkbox" id="check_', id, '"/>',
            '<span>', '</span>',
            '</label>',
        ].join(''));
        $(['#checkbox_', id].join('')).on('change', data, dixim.proxy(this._changeCheckbox, this));
    }

    if (data.class === 'container') {
        rowSelector.addClass('content_folder');
        rowSelector.find('[name="clickable"]').on('click', data, dixim.proxy(this._clickSelectContent, this));
    } else {
        rowSelector.addClass('list_content');
        rowSelector.find('.list_detail').append([
            '<p class="content-info">', Formatter.stringifySize(data.size), '</p>',
            '<p class="content-info">', Formatter.stringifyDate(Formatter.dcDateToDate(data.date)), '</p>',
        ].join(''));
        if (typeof data.atsTranscodeState !== 'undefined') {
            rowSelector.find('.list_detail').append([
                '<p class="content-info">', this._formatTranscodeState(data.atsTranscodeState), '</p>',
            ].join(''));
        }
        if (typeof data.autoRemoveProtected !== 'undefined' && data.autoRemoveProtected) {
            rowSelector.find('.list_detail').append([
                '<p class="content-info">', _('contents_auto_remove_protected'), '</p>',
            ].join(''));
        }
    }
};

prototype.noContent = function() {
    this._browsedData = {};

    $('#contentField').html([
        '<div class="txt_none error-text-field">',
        '<span>', _('contents_no_content'), '</span>',
        '</div>',
    ].join(''));
};

prototype._formatTranscodeState = function(state) {
    var stateNum = 0;

    switch(state) {
        case 1:
        case 2:
        case 4:
        case 8:
            stateNum = state;
            break;
    }

    return _(['contents_compress_state_', stateNum].join(''));
};

prototype.cleanContent = function() {
    this._browsedData = {};

    $('#contentField').empty();
};

prototype.checkActionBarStatus = function(operationStatus) {
    var isOnFlag = function() {
        for (var i = 0, len = arguments.length; i < len; i += 1) {
            if (!Enum.isOnFlag(operationStatus, OperationMenu[arguments[i]])) return false;
        }
        return true;
    };
    var isOffFlag = function() {
        for (var i = 0, len = arguments.length; i < len; i += 1) {
            if (!Enum.isOffFlag(operationStatus, OperationMenu[arguments[i]])) return false;
        }
        return true;
    };

    if ($('#contentField [type="checkbox"]').length === 0) {
        UiUtils.disableActionBar('ab_select');
    } else {
        UiUtils.enableActionBar('ab_select');
    }

    operationStatus &= ~(OperationMenu.MULTIPLE | OperationMenu.NO_SELECTED | OperationMenu.ITEM | OperationMenu.CONTAINER);
    if ($('#contentField [type="checkbox"]:checked').length > 0) operationStatus |= OperationMenu.MULTIPLE;
    if ($('#contentField [type="checkbox"]:checked').length === 0) operationStatus |= OperationMenu.NO_SELECTED;

    if (isOffFlag('CATEGORY_CONTENTS', 'SEARCH_PAGE')||
       (isOnFlag('CATEGORY_CONTENTS') && isOffFlag('NO_SELECTED')) ||
       (isOnFlag('SEARCH_PAGE') && isOffFlag('NO_SELECTED'))
    ) {
        UiUtils.enableActionBar('ab_operate');
    } else {
        UiUtils.disableActionBar('ab_operate');
    }
};

prototype.switchSelect = function() {
    var checkboxSelector = $('#contentField [type="checkbox"]');
    var numberOfNotChecked = checkboxSelector.not(':checked').length;

    checkboxSelector.prop('checked', (numberOfNotChecked > 0));
};

prototype._changeCheckbox = function(e) {
    this.dispatchEvent(new Event(CHANGE_CHECKBOX, e.data));
};

prototype._clickSelectContent = function(e) {
    this.dispatchEvent(new Event(SELECT_CONTENT, e.data));
};

prototype._clickSelect = function() {
    this.dispatchEvent(new Event(SELECT));
};

prototype._clickOperate = function() {
    var browsedData = this._browsedData;
    var dataList = [];

    $('#contentField [type="checkbox"]:checked').each(function() {
        dataList.push(browsedData[$(this).prop('id').substr(6)]);
    });
    this.dispatchEvent(new Event(OPERATE, {dataList: dataList}));
};

prototype._clickRefresh = function() {
    this.dispatchEvent(new Event(REFRESH));
};

prototype._clickSearch = function() {
    this.dispatchEvent(new Event(SEARCH));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

}());
